# smile-datasets

![Python package](https://github.com/luozhouyang/naivenlp-datasets/workflows/Python%20package/badge.svg)
[![PyPI version](https://badge.fury.io/py/naivenlp-datasets.svg)](https://badge.fury.io/py/naivenlp-datasets)
[![Python](https://img.shields.io/pypi/pyversions/naivenlp-datasets.svg?style=plastic)](https://badge.fury.io/py/naivenlp-datasets)


Data pipelines for both **TensorFlow** and **PyTorch** !

If you want to load public datasets, try:

* [tensorflow/datasets](https://github.com/tensorflow/datasets)
* [huggingface/datasets](https://github.com/huggingface/datasets)

If you want to load local, personal dataset with minimized boilerplate, use **naivenlp-datasets**!

## installation

```bash
pip install -U naivenlp-datasets
```

> If you work with PyTorch, you should install [PyTorch](https://pytorch.org/get-started/locally/) first.

> If you work with TensorFlow, you should install [TensorFlow](https://github.com/tensorflow/tensorflow) first.

## Usage

Here are few examples to show you how to use this library.
